# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AlertManagerContactPointArgs',
    'AlertManagerContactPointArgsDict',
    'CockpitEndpointArgs',
    'CockpitEndpointArgsDict',
    'CockpitPushUrlArgs',
    'CockpitPushUrlArgsDict',
    'ExporterDatadogDestinationArgs',
    'ExporterDatadogDestinationArgsDict',
    'ExporterOtlpDestinationArgs',
    'ExporterOtlpDestinationArgsDict',
    'TokenScopesArgs',
    'TokenScopesArgsDict',
]

MYPY = False

if not MYPY:
    class AlertManagerContactPointArgsDict(TypedDict):
        email: NotRequired[pulumi.Input[_builtins.str]]
        """
        Email addresses for the alert receivers
        """
elif False:
    AlertManagerContactPointArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AlertManagerContactPointArgs:
    def __init__(__self__, *,
                 email: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] email: Email addresses for the alert receivers
        """
        if email is not None:
            pulumi.set(__self__, "email", email)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Email addresses for the alert receivers
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)


if not MYPY:
    class CockpitEndpointArgsDict(TypedDict):
        alertmanager_url: NotRequired[pulumi.Input[_builtins.str]]
        """
        (Deprecated) URL for the [Alert manager](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#alert-manager).
        """
        grafana_url: NotRequired[pulumi.Input[_builtins.str]]
        """
        (Deprecated) URL for Grafana.
        """
        logs_url: NotRequired[pulumi.Input[_builtins.str]]
        """
        (Deprecated) URL for [logs](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#logs) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        metrics_url: NotRequired[pulumi.Input[_builtins.str]]
        """
        (Deprecated) URL for [metrics](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#metric) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        traces_url: NotRequired[pulumi.Input[_builtins.str]]
        """
        (Deprecated) URL for [traces](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#traces) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
elif False:
    CockpitEndpointArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class CockpitEndpointArgs:
    def __init__(__self__, *,
                 alertmanager_url: Optional[pulumi.Input[_builtins.str]] = None,
                 grafana_url: Optional[pulumi.Input[_builtins.str]] = None,
                 logs_url: Optional[pulumi.Input[_builtins.str]] = None,
                 metrics_url: Optional[pulumi.Input[_builtins.str]] = None,
                 traces_url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] alertmanager_url: (Deprecated) URL for the [Alert manager](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#alert-manager).
        :param pulumi.Input[_builtins.str] grafana_url: (Deprecated) URL for Grafana.
        :param pulumi.Input[_builtins.str] logs_url: (Deprecated) URL for [logs](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#logs) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        :param pulumi.Input[_builtins.str] metrics_url: (Deprecated) URL for [metrics](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#metric) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        :param pulumi.Input[_builtins.str] traces_url: (Deprecated) URL for [traces](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#traces) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        if alertmanager_url is not None:
            pulumi.set(__self__, "alertmanager_url", alertmanager_url)
        if grafana_url is not None:
            pulumi.set(__self__, "grafana_url", grafana_url)
        if logs_url is not None:
            pulumi.set(__self__, "logs_url", logs_url)
        if metrics_url is not None:
            pulumi.set(__self__, "metrics_url", metrics_url)
        if traces_url is not None:
            pulumi.set(__self__, "traces_url", traces_url)

    @_builtins.property
    @pulumi.getter(name="alertmanagerUrl")
    def alertmanager_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Deprecated) URL for the [Alert manager](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#alert-manager).
        """
        return pulumi.get(self, "alertmanager_url")

    @alertmanager_url.setter
    def alertmanager_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "alertmanager_url", value)

    @_builtins.property
    @pulumi.getter(name="grafanaUrl")
    def grafana_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Deprecated) URL for Grafana.
        """
        return pulumi.get(self, "grafana_url")

    @grafana_url.setter
    def grafana_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "grafana_url", value)

    @_builtins.property
    @pulumi.getter(name="logsUrl")
    def logs_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Deprecated) URL for [logs](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#logs) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        return pulumi.get(self, "logs_url")

    @logs_url.setter
    def logs_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "logs_url", value)

    @_builtins.property
    @pulumi.getter(name="metricsUrl")
    def metrics_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Deprecated) URL for [metrics](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#metric) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        return pulumi.get(self, "metrics_url")

    @metrics_url.setter
    def metrics_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "metrics_url", value)

    @_builtins.property
    @pulumi.getter(name="tracesUrl")
    def traces_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Deprecated) URL for [traces](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#traces) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        return pulumi.get(self, "traces_url")

    @traces_url.setter
    def traces_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "traces_url", value)


if not MYPY:
    class CockpitPushUrlArgsDict(TypedDict):
        push_logs_url: NotRequired[pulumi.Input[_builtins.str]]
        """
        Push URL for logs (Grafana Loki)
        """
        push_metrics_url: NotRequired[pulumi.Input[_builtins.str]]
        """
        Push URL for metrics (Grafana Mimir)
        """
elif False:
    CockpitPushUrlArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class CockpitPushUrlArgs:
    def __init__(__self__, *,
                 push_logs_url: Optional[pulumi.Input[_builtins.str]] = None,
                 push_metrics_url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] push_logs_url: Push URL for logs (Grafana Loki)
        :param pulumi.Input[_builtins.str] push_metrics_url: Push URL for metrics (Grafana Mimir)
        """
        if push_logs_url is not None:
            pulumi.set(__self__, "push_logs_url", push_logs_url)
        if push_metrics_url is not None:
            pulumi.set(__self__, "push_metrics_url", push_metrics_url)

    @_builtins.property
    @pulumi.getter(name="pushLogsUrl")
    def push_logs_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Push URL for logs (Grafana Loki)
        """
        return pulumi.get(self, "push_logs_url")

    @push_logs_url.setter
    def push_logs_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "push_logs_url", value)

    @_builtins.property
    @pulumi.getter(name="pushMetricsUrl")
    def push_metrics_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Push URL for metrics (Grafana Mimir)
        """
        return pulumi.get(self, "push_metrics_url")

    @push_metrics_url.setter
    def push_metrics_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "push_metrics_url", value)


if not MYPY:
    class ExporterDatadogDestinationArgsDict(TypedDict):
        api_key: pulumi.Input[_builtins.str]
        """
        Datadog API key. Sensitive.
        """
        endpoint: NotRequired[pulumi.Input[_builtins.str]]
        """
        Datadog endpoint URL. Defaults to `https://api.datadoghq.com`.
        """
elif False:
    ExporterDatadogDestinationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ExporterDatadogDestinationArgs:
    def __init__(__self__, *,
                 api_key: pulumi.Input[_builtins.str],
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] api_key: Datadog API key. Sensitive.
        :param pulumi.Input[_builtins.str] endpoint: Datadog endpoint URL. Defaults to `https://api.datadoghq.com`.
        """
        pulumi.set(__self__, "api_key", api_key)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> pulumi.Input[_builtins.str]:
        """
        Datadog API key. Sensitive.
        """
        return pulumi.get(self, "api_key")

    @api_key.setter
    def api_key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "api_key", value)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Datadog endpoint URL. Defaults to `https://api.datadoghq.com`.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint", value)


if not MYPY:
    class ExporterOtlpDestinationArgsDict(TypedDict):
        endpoint: pulumi.Input[_builtins.str]
        """
        OTLP endpoint URL.
        """
        headers: NotRequired[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]
        """
        Headers to include in requests.
        """
elif False:
    ExporterOtlpDestinationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ExporterOtlpDestinationArgs:
    def __init__(__self__, *,
                 endpoint: pulumi.Input[_builtins.str],
                 headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        :param pulumi.Input[_builtins.str] endpoint: OTLP endpoint URL.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] headers: Headers to include in requests.
        """
        pulumi.set(__self__, "endpoint", endpoint)
        if headers is not None:
            pulumi.set(__self__, "headers", headers)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> pulumi.Input[_builtins.str]:
        """
        OTLP endpoint URL.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "endpoint", value)

    @_builtins.property
    @pulumi.getter
    def headers(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Headers to include in requests.
        """
        return pulumi.get(self, "headers")

    @headers.setter
    def headers(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "headers", value)


if not MYPY:
    class TokenScopesArgsDict(TypedDict):
        query_logs: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Permission to query logs.
        """
        query_metrics: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Permission to query metrics.
        """
        query_traces: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Permission to query traces.
        """
        setup_alerts: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Permission to set up alerts.
        """
        setup_logs_rules: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Permission to set up logs rules.
        """
        setup_metrics_rules: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Permission to set up metrics rules.
        """
        write_logs: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Permission to write logs.
        """
        write_metrics: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Permission to write metrics.
        """
        write_traces: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Permission to write traces.
        """
elif False:
    TokenScopesArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TokenScopesArgs:
    def __init__(__self__, *,
                 query_logs: Optional[pulumi.Input[_builtins.bool]] = None,
                 query_metrics: Optional[pulumi.Input[_builtins.bool]] = None,
                 query_traces: Optional[pulumi.Input[_builtins.bool]] = None,
                 setup_alerts: Optional[pulumi.Input[_builtins.bool]] = None,
                 setup_logs_rules: Optional[pulumi.Input[_builtins.bool]] = None,
                 setup_metrics_rules: Optional[pulumi.Input[_builtins.bool]] = None,
                 write_logs: Optional[pulumi.Input[_builtins.bool]] = None,
                 write_metrics: Optional[pulumi.Input[_builtins.bool]] = None,
                 write_traces: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        :param pulumi.Input[_builtins.bool] query_logs: Permission to query logs.
        :param pulumi.Input[_builtins.bool] query_metrics: Permission to query metrics.
        :param pulumi.Input[_builtins.bool] query_traces: Permission to query traces.
        :param pulumi.Input[_builtins.bool] setup_alerts: Permission to set up alerts.
        :param pulumi.Input[_builtins.bool] setup_logs_rules: Permission to set up logs rules.
        :param pulumi.Input[_builtins.bool] setup_metrics_rules: Permission to set up metrics rules.
        :param pulumi.Input[_builtins.bool] write_logs: Permission to write logs.
        :param pulumi.Input[_builtins.bool] write_metrics: Permission to write metrics.
        :param pulumi.Input[_builtins.bool] write_traces: Permission to write traces.
        """
        if query_logs is not None:
            pulumi.set(__self__, "query_logs", query_logs)
        if query_metrics is not None:
            pulumi.set(__self__, "query_metrics", query_metrics)
        if query_traces is not None:
            pulumi.set(__self__, "query_traces", query_traces)
        if setup_alerts is not None:
            pulumi.set(__self__, "setup_alerts", setup_alerts)
        if setup_logs_rules is not None:
            pulumi.set(__self__, "setup_logs_rules", setup_logs_rules)
        if setup_metrics_rules is not None:
            pulumi.set(__self__, "setup_metrics_rules", setup_metrics_rules)
        if write_logs is not None:
            pulumi.set(__self__, "write_logs", write_logs)
        if write_metrics is not None:
            pulumi.set(__self__, "write_metrics", write_metrics)
        if write_traces is not None:
            pulumi.set(__self__, "write_traces", write_traces)

    @_builtins.property
    @pulumi.getter(name="queryLogs")
    def query_logs(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Permission to query logs.
        """
        return pulumi.get(self, "query_logs")

    @query_logs.setter
    def query_logs(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "query_logs", value)

    @_builtins.property
    @pulumi.getter(name="queryMetrics")
    def query_metrics(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Permission to query metrics.
        """
        return pulumi.get(self, "query_metrics")

    @query_metrics.setter
    def query_metrics(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "query_metrics", value)

    @_builtins.property
    @pulumi.getter(name="queryTraces")
    def query_traces(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Permission to query traces.
        """
        return pulumi.get(self, "query_traces")

    @query_traces.setter
    def query_traces(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "query_traces", value)

    @_builtins.property
    @pulumi.getter(name="setupAlerts")
    def setup_alerts(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Permission to set up alerts.
        """
        return pulumi.get(self, "setup_alerts")

    @setup_alerts.setter
    def setup_alerts(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "setup_alerts", value)

    @_builtins.property
    @pulumi.getter(name="setupLogsRules")
    def setup_logs_rules(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Permission to set up logs rules.
        """
        return pulumi.get(self, "setup_logs_rules")

    @setup_logs_rules.setter
    def setup_logs_rules(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "setup_logs_rules", value)

    @_builtins.property
    @pulumi.getter(name="setupMetricsRules")
    def setup_metrics_rules(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Permission to set up metrics rules.
        """
        return pulumi.get(self, "setup_metrics_rules")

    @setup_metrics_rules.setter
    def setup_metrics_rules(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "setup_metrics_rules", value)

    @_builtins.property
    @pulumi.getter(name="writeLogs")
    def write_logs(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Permission to write logs.
        """
        return pulumi.get(self, "write_logs")

    @write_logs.setter
    def write_logs(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "write_logs", value)

    @_builtins.property
    @pulumi.getter(name="writeMetrics")
    def write_metrics(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Permission to write metrics.
        """
        return pulumi.get(self, "write_metrics")

    @write_metrics.setter
    def write_metrics(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "write_metrics", value)

    @_builtins.property
    @pulumi.getter(name="writeTraces")
    def write_traces(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Permission to write traces.
        """
        return pulumi.get(self, "write_traces")

    @write_traces.setter
    def write_traces(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "write_traces", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'SnsCredentialsPermissions',
    'SqsCredentialsPermissions',
    'SqsQueueDeadLetterQueue',
]

@pulumi.output_type
class SnsCredentialsPermissions(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "canManage":
            suggest = "can_manage"
        elif key == "canPublish":
            suggest = "can_publish"
        elif key == "canReceive":
            suggest = "can_receive"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SnsCredentialsPermissions. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SnsCredentialsPermissions.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SnsCredentialsPermissions.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 can_manage: Optional[_builtins.bool] = None,
                 can_publish: Optional[_builtins.bool] = None,
                 can_receive: Optional[_builtins.bool] = None):
        """
        :param _builtins.bool can_manage: . Defines whether the user can manage the associated resource(s).
        :param _builtins.bool can_publish: . Defines whether the user can publish messages to the service.
        :param _builtins.bool can_receive: . Defines whether the user can receive messages from the service.
        """
        if can_manage is not None:
            pulumi.set(__self__, "can_manage", can_manage)
        if can_publish is not None:
            pulumi.set(__self__, "can_publish", can_publish)
        if can_receive is not None:
            pulumi.set(__self__, "can_receive", can_receive)

    @_builtins.property
    @pulumi.getter(name="canManage")
    def can_manage(self) -> Optional[_builtins.bool]:
        """
        . Defines whether the user can manage the associated resource(s).
        """
        return pulumi.get(self, "can_manage")

    @_builtins.property
    @pulumi.getter(name="canPublish")
    def can_publish(self) -> Optional[_builtins.bool]:
        """
        . Defines whether the user can publish messages to the service.
        """
        return pulumi.get(self, "can_publish")

    @_builtins.property
    @pulumi.getter(name="canReceive")
    def can_receive(self) -> Optional[_builtins.bool]:
        """
        . Defines whether the user can receive messages from the service.
        """
        return pulumi.get(self, "can_receive")


@pulumi.output_type
class SqsCredentialsPermissions(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "canManage":
            suggest = "can_manage"
        elif key == "canPublish":
            suggest = "can_publish"
        elif key == "canReceive":
            suggest = "can_receive"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SqsCredentialsPermissions. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SqsCredentialsPermissions.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SqsCredentialsPermissions.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 can_manage: Optional[_builtins.bool] = None,
                 can_publish: Optional[_builtins.bool] = None,
                 can_receive: Optional[_builtins.bool] = None):
        """
        :param _builtins.bool can_manage: . Defines whether the user can manage the associated resource(s).
        :param _builtins.bool can_publish: . Defines whether the user can publish messages to the service.
        :param _builtins.bool can_receive: . Defines whether the user can receive messages from the service.
        """
        if can_manage is not None:
            pulumi.set(__self__, "can_manage", can_manage)
        if can_publish is not None:
            pulumi.set(__self__, "can_publish", can_publish)
        if can_receive is not None:
            pulumi.set(__self__, "can_receive", can_receive)

    @_builtins.property
    @pulumi.getter(name="canManage")
    def can_manage(self) -> Optional[_builtins.bool]:
        """
        . Defines whether the user can manage the associated resource(s).
        """
        return pulumi.get(self, "can_manage")

    @_builtins.property
    @pulumi.getter(name="canPublish")
    def can_publish(self) -> Optional[_builtins.bool]:
        """
        . Defines whether the user can publish messages to the service.
        """
        return pulumi.get(self, "can_publish")

    @_builtins.property
    @pulumi.getter(name="canReceive")
    def can_receive(self) -> Optional[_builtins.bool]:
        """
        . Defines whether the user can receive messages from the service.
        """
        return pulumi.get(self, "can_receive")


@pulumi.output_type
class SqsQueueDeadLetterQueue(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "maxReceiveCount":
            suggest = "max_receive_count"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SqsQueueDeadLetterQueue. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SqsQueueDeadLetterQueue.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SqsQueueDeadLetterQueue.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 id: _builtins.str,
                 max_receive_count: _builtins.int):
        """
        :param _builtins.str id: The ID of the queue with format `{region/{project-id}/{queue-name}`
        :param _builtins.int max_receive_count: The number of times a message is delivered to the source queue before being sent to the dead-letter queue. Must be between 1 and 1,000.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "max_receive_count", max_receive_count)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the queue with format `{region/{project-id}/{queue-name}`
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="maxReceiveCount")
    def max_receive_count(self) -> _builtins.int:
        """
        The number of times a message is delivered to the source queue before being sent to the dead-letter queue. Must be between 1 and 1,000.
        """
        return pulumi.get(self, "max_receive_count")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetClusterResult',
    'AwaitableGetClusterResult',
    'get_cluster',
    'get_cluster_output',
]

@pulumi.output_type
class GetClusterResult:
    """
    A collection of values returned by getCluster.
    """
    def __init__(__self__, cluster_id=None, created_at=None, id=None, name=None, node_amount=None, node_type=None, password=None, private_networks=None, project_id=None, public_networks=None, region=None, status=None, tags=None, updated_at=None, user_name=None, version=None, volume_size_in_gb=None, volume_type=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if node_amount and not isinstance(node_amount, int):
            raise TypeError("Expected argument 'node_amount' to be a int")
        pulumi.set(__self__, "node_amount", node_amount)
        if node_type and not isinstance(node_type, str):
            raise TypeError("Expected argument 'node_type' to be a str")
        pulumi.set(__self__, "node_type", node_type)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if private_networks and not isinstance(private_networks, list):
            raise TypeError("Expected argument 'private_networks' to be a list")
        pulumi.set(__self__, "private_networks", private_networks)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if public_networks and not isinstance(public_networks, list):
            raise TypeError("Expected argument 'public_networks' to be a list")
        pulumi.set(__self__, "public_networks", public_networks)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if user_name and not isinstance(user_name, str):
            raise TypeError("Expected argument 'user_name' to be a str")
        pulumi.set(__self__, "user_name", user_name)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)
        if volume_size_in_gb and not isinstance(volume_size_in_gb, int):
            raise TypeError("Expected argument 'volume_size_in_gb' to be a int")
        pulumi.set(__self__, "volume_size_in_gb", volume_size_in_gb)
        if volume_type and not isinstance(volume_type, str):
            raise TypeError("Expected argument 'volume_type' to be a str")
        pulumi.set(__self__, "volume_type", volume_type)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[_builtins.str]:
        """
        The ID of the Kafka cluster
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Date and time of cluster creation (RFC 3339 format)
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the Kafka cluster
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeAmount")
    def node_amount(self) -> _builtins.int:
        """
        Number of nodes in the cluster
        """
        return pulumi.get(self, "node_amount")

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> _builtins.str:
        """
        Node type to use for the cluster
        """
        return pulumi.get(self, "node_type")

    @_builtins.property
    @pulumi.getter
    def password(self) -> _builtins.str:
        """
        Password for the Kafka user
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter(name="privateNetworks")
    def private_networks(self) -> Sequence['outputs.GetClusterPrivateNetworkResult']:
        """
        Private network to expose your Kafka cluster
        """
        return pulumi.get(self, "private_networks")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        The project_id you want to attach the resource to
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="publicNetworks")
    def public_networks(self) -> Sequence['outputs.GetClusterPublicNetworkResult']:
        """
        Public endpoint configuration
        """
        return pulumi.get(self, "public_networks")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        """
        The region you want to attach the resource to
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the cluster
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        List of tags to apply
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        Date and time of cluster last update (RFC 3339 format)
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> _builtins.str:
        """
        Username for the Kafka user
        """
        return pulumi.get(self, "user_name")

    @_builtins.property
    @pulumi.getter
    def version(self) -> _builtins.str:
        """
        Kafka version to use
        """
        return pulumi.get(self, "version")

    @_builtins.property
    @pulumi.getter(name="volumeSizeInGb")
    def volume_size_in_gb(self) -> _builtins.int:
        """
        Volume size in GB
        """
        return pulumi.get(self, "volume_size_in_gb")

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> _builtins.str:
        """
        Type of volume where data is stored
        """
        return pulumi.get(self, "volume_type")


class AwaitableGetClusterResult(GetClusterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClusterResult(
            cluster_id=self.cluster_id,
            created_at=self.created_at,
            id=self.id,
            name=self.name,
            node_amount=self.node_amount,
            node_type=self.node_type,
            password=self.password,
            private_networks=self.private_networks,
            project_id=self.project_id,
            public_networks=self.public_networks,
            region=self.region,
            status=self.status,
            tags=self.tags,
            updated_at=self.updated_at,
            user_name=self.user_name,
            version=self.version,
            volume_size_in_gb=self.volume_size_in_gb,
            volume_type=self.volume_type)


def get_cluster(cluster_id: Optional[_builtins.str] = None,
                name: Optional[_builtins.str] = None,
                project_id: Optional[_builtins.str] = None,
                region: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetClusterResult:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str cluster_id: The ID of the Kafka cluster
    :param _builtins.str name: Name of the Kafka cluster
    :param _builtins.str project_id: The project_id you want to attach the resource to
    :param _builtins.str region: The region you want to attach the resource to
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:kafka/getCluster:getCluster', __args__, opts=opts, typ=GetClusterResult).value

    return AwaitableGetClusterResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        node_amount=pulumi.get(__ret__, 'node_amount'),
        node_type=pulumi.get(__ret__, 'node_type'),
        password=pulumi.get(__ret__, 'password'),
        private_networks=pulumi.get(__ret__, 'private_networks'),
        project_id=pulumi.get(__ret__, 'project_id'),
        public_networks=pulumi.get(__ret__, 'public_networks'),
        region=pulumi.get(__ret__, 'region'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        user_name=pulumi.get(__ret__, 'user_name'),
        version=pulumi.get(__ret__, 'version'),
        volume_size_in_gb=pulumi.get(__ret__, 'volume_size_in_gb'),
        volume_type=pulumi.get(__ret__, 'volume_type'))
def get_cluster_output(cluster_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetClusterResult]:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.str cluster_id: The ID of the Kafka cluster
    :param _builtins.str name: Name of the Kafka cluster
    :param _builtins.str project_id: The project_id you want to attach the resource to
    :param _builtins.str region: The region you want to attach the resource to
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:kafka/getCluster:getCluster', __args__, opts=opts, typ=GetClusterResult)
    return __ret__.apply(lambda __response__: GetClusterResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        node_amount=pulumi.get(__response__, 'node_amount'),
        node_type=pulumi.get(__response__, 'node_type'),
        password=pulumi.get(__response__, 'password'),
        private_networks=pulumi.get(__response__, 'private_networks'),
        project_id=pulumi.get(__response__, 'project_id'),
        public_networks=pulumi.get(__response__, 'public_networks'),
        region=pulumi.get(__response__, 'region'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        user_name=pulumi.get(__response__, 'user_name'),
        version=pulumi.get(__response__, 'version'),
        volume_size_in_gb=pulumi.get(__response__, 'volume_size_in_gb'),
        volume_type=pulumi.get(__response__, 'volume_type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'BackendStageLbBackendConfigArgs',
    'BackendStageLbBackendConfigArgsDict',
    'BackendStageLbBackendConfigLbConfigArgs',
    'BackendStageLbBackendConfigLbConfigArgsDict',
    'BackendStageS3BackendConfigArgs',
    'BackendStageS3BackendConfigArgsDict',
    'CacheStagePurgeRequestArgs',
    'CacheStagePurgeRequestArgsDict',
    'RouteStageRuleArgs',
    'RouteStageRuleArgsDict',
    'RouteStageRuleRuleHttpMatchArgs',
    'RouteStageRuleRuleHttpMatchArgsDict',
    'RouteStageRuleRuleHttpMatchPathFilterArgs',
    'RouteStageRuleRuleHttpMatchPathFilterArgsDict',
    'TlsStageSecretArgs',
    'TlsStageSecretArgsDict',
]

MYPY = False

if not MYPY:
    class BackendStageLbBackendConfigArgsDict(TypedDict):
        lb_config: NotRequired[pulumi.Input['BackendStageLbBackendConfigLbConfigArgsDict']]
        """
        The Load Balancer config.
        """
elif False:
    BackendStageLbBackendConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class BackendStageLbBackendConfigArgs:
    def __init__(__self__, *,
                 lb_config: Optional[pulumi.Input['BackendStageLbBackendConfigLbConfigArgs']] = None):
        """
        :param pulumi.Input['BackendStageLbBackendConfigLbConfigArgs'] lb_config: The Load Balancer config.
        """
        if lb_config is not None:
            pulumi.set(__self__, "lb_config", lb_config)

    @_builtins.property
    @pulumi.getter(name="lbConfig")
    def lb_config(self) -> Optional[pulumi.Input['BackendStageLbBackendConfigLbConfigArgs']]:
        """
        The Load Balancer config.
        """
        return pulumi.get(self, "lb_config")

    @lb_config.setter
    def lb_config(self, value: Optional[pulumi.Input['BackendStageLbBackendConfigLbConfigArgs']]):
        pulumi.set(self, "lb_config", value)


if not MYPY:
    class BackendStageLbBackendConfigLbConfigArgsDict(TypedDict):
        domain_name: NotRequired[pulumi.Input[_builtins.str]]
        """
        The Fully Qualified Domain Name (in the format subdomain.example.com) to use in HTTP requests sent towards your Load Balancer.
        """
        frontend_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the frontend.
        """
        has_websocket: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Defines whether to forward websocket requests to the load balancer.
        """
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the Load Balancer.
        """
        is_ssl: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Defines whether the Load Balancer's frontend handles SSL connections.
        """
        zone: NotRequired[pulumi.Input[_builtins.str]]
        """
        `zone`) The zone of the Load Balancer.
        """
elif False:
    BackendStageLbBackendConfigLbConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class BackendStageLbBackendConfigLbConfigArgs:
    def __init__(__self__, *,
                 domain_name: Optional[pulumi.Input[_builtins.str]] = None,
                 frontend_id: Optional[pulumi.Input[_builtins.str]] = None,
                 has_websocket: Optional[pulumi.Input[_builtins.bool]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_ssl: Optional[pulumi.Input[_builtins.bool]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] domain_name: The Fully Qualified Domain Name (in the format subdomain.example.com) to use in HTTP requests sent towards your Load Balancer.
        :param pulumi.Input[_builtins.str] frontend_id: The ID of the frontend.
        :param pulumi.Input[_builtins.bool] has_websocket: Defines whether to forward websocket requests to the load balancer.
        :param pulumi.Input[_builtins.str] id: The ID of the Load Balancer.
        :param pulumi.Input[_builtins.bool] is_ssl: Defines whether the Load Balancer's frontend handles SSL connections.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone of the Load Balancer.
        """
        if domain_name is not None:
            pulumi.set(__self__, "domain_name", domain_name)
        if frontend_id is not None:
            pulumi.set(__self__, "frontend_id", frontend_id)
        if has_websocket is not None:
            pulumi.set(__self__, "has_websocket", has_websocket)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_ssl is not None:
            pulumi.set(__self__, "is_ssl", is_ssl)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Fully Qualified Domain Name (in the format subdomain.example.com) to use in HTTP requests sent towards your Load Balancer.
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain_name", value)

    @_builtins.property
    @pulumi.getter(name="frontendId")
    def frontend_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the frontend.
        """
        return pulumi.get(self, "frontend_id")

    @frontend_id.setter
    def frontend_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "frontend_id", value)

    @_builtins.property
    @pulumi.getter(name="hasWebsocket")
    def has_websocket(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines whether to forward websocket requests to the load balancer.
        """
        return pulumi.get(self, "has_websocket")

    @has_websocket.setter
    def has_websocket(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "has_websocket", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Load Balancer.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter(name="isSsl")
    def is_ssl(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines whether the Load Balancer's frontend handles SSL connections.
        """
        return pulumi.get(self, "is_ssl")

    @is_ssl.setter
    def is_ssl(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_ssl", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone of the Load Balancer.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


if not MYPY:
    class BackendStageS3BackendConfigArgsDict(TypedDict):
        bucket_name: NotRequired[pulumi.Input[_builtins.str]]
        """
        The name of the Bucket.
        """
        bucket_region: NotRequired[pulumi.Input[_builtins.str]]
        """
        The region of the Bucket.
        """
        is_website: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Defines whether the bucket website feature is enabled.
        """
elif False:
    BackendStageS3BackendConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class BackendStageS3BackendConfigArgs:
    def __init__(__self__, *,
                 bucket_name: Optional[pulumi.Input[_builtins.str]] = None,
                 bucket_region: Optional[pulumi.Input[_builtins.str]] = None,
                 is_website: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        :param pulumi.Input[_builtins.str] bucket_name: The name of the Bucket.
        :param pulumi.Input[_builtins.str] bucket_region: The region of the Bucket.
        :param pulumi.Input[_builtins.bool] is_website: Defines whether the bucket website feature is enabled.
        """
        if bucket_name is not None:
            pulumi.set(__self__, "bucket_name", bucket_name)
        if bucket_region is not None:
            pulumi.set(__self__, "bucket_region", bucket_region)
        if is_website is not None:
            pulumi.set(__self__, "is_website", is_website)

    @_builtins.property
    @pulumi.getter(name="bucketName")
    def bucket_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Bucket.
        """
        return pulumi.get(self, "bucket_name")

    @bucket_name.setter
    def bucket_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "bucket_name", value)

    @_builtins.property
    @pulumi.getter(name="bucketRegion")
    def bucket_region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region of the Bucket.
        """
        return pulumi.get(self, "bucket_region")

    @bucket_region.setter
    def bucket_region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "bucket_region", value)

    @_builtins.property
    @pulumi.getter(name="isWebsite")
    def is_website(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines whether the bucket website feature is enabled.
        """
        return pulumi.get(self, "is_website")

    @is_website.setter
    def is_website(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_website", value)


if not MYPY:
    class CacheStagePurgeRequestArgsDict(TypedDict):
        all: NotRequired[pulumi.Input[_builtins.bool]]
        """
        Defines whether to purge all content.
        """
        assets: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        The list of asserts to purge.
        """
        pipeline_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The pipeline ID in which the purge request will be created.
        """
elif False:
    CacheStagePurgeRequestArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class CacheStagePurgeRequestArgs:
    def __init__(__self__, *,
                 all: Optional[pulumi.Input[_builtins.bool]] = None,
                 assets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.bool] all: Defines whether to purge all content.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] assets: The list of asserts to purge.
        :param pulumi.Input[_builtins.str] pipeline_id: The pipeline ID in which the purge request will be created.
        """
        if all is not None:
            pulumi.set(__self__, "all", all)
        if assets is not None:
            pulumi.set(__self__, "assets", assets)
        if pipeline_id is not None:
            pulumi.set(__self__, "pipeline_id", pipeline_id)

    @_builtins.property
    @pulumi.getter
    def all(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defines whether to purge all content.
        """
        return pulumi.get(self, "all")

    @all.setter
    def all(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "all", value)

    @_builtins.property
    @pulumi.getter
    def assets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of asserts to purge.
        """
        return pulumi.get(self, "assets")

    @assets.setter
    def assets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "assets", value)

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The pipeline ID in which the purge request will be created.
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pipeline_id", value)


if not MYPY:
    class RouteStageRuleArgsDict(TypedDict):
        backend_stage_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the backend stage that requests matching the rule should be forwarded to. Conflicts with `waf_stage_id` within the same rule.
        """
        rule_http_match: NotRequired[pulumi.Input['RouteStageRuleRuleHttpMatchArgsDict']]
        """
        The rule condition to be matched. Requests matching the condition defined here will be forwarded to the stage specified by `backend_stage_id` or `waf_stage_id`. Requests that do not match will be checked by the next rule's condition.
        """
        waf_stage_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the WAF stage that requests matching the rule should be forwarded to. Conflicts with `backend_stage_id` within the same rule.
        """
elif False:
    RouteStageRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteStageRuleArgs:
    def __init__(__self__, *,
                 backend_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_http_match: Optional[pulumi.Input['RouteStageRuleRuleHttpMatchArgs']] = None,
                 waf_stage_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] backend_stage_id: The ID of the backend stage that requests matching the rule should be forwarded to. Conflicts with `waf_stage_id` within the same rule.
        :param pulumi.Input['RouteStageRuleRuleHttpMatchArgs'] rule_http_match: The rule condition to be matched. Requests matching the condition defined here will be forwarded to the stage specified by `backend_stage_id` or `waf_stage_id`. Requests that do not match will be checked by the next rule's condition.
        :param pulumi.Input[_builtins.str] waf_stage_id: The ID of the WAF stage that requests matching the rule should be forwarded to. Conflicts with `backend_stage_id` within the same rule.
        """
        if backend_stage_id is not None:
            pulumi.set(__self__, "backend_stage_id", backend_stage_id)
        if rule_http_match is not None:
            pulumi.set(__self__, "rule_http_match", rule_http_match)
        if waf_stage_id is not None:
            pulumi.set(__self__, "waf_stage_id", waf_stage_id)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the backend stage that requests matching the rule should be forwarded to. Conflicts with `waf_stage_id` within the same rule.
        """
        return pulumi.get(self, "backend_stage_id")

    @backend_stage_id.setter
    def backend_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend_stage_id", value)

    @_builtins.property
    @pulumi.getter(name="ruleHttpMatch")
    def rule_http_match(self) -> Optional[pulumi.Input['RouteStageRuleRuleHttpMatchArgs']]:
        """
        The rule condition to be matched. Requests matching the condition defined here will be forwarded to the stage specified by `backend_stage_id` or `waf_stage_id`. Requests that do not match will be checked by the next rule's condition.
        """
        return pulumi.get(self, "rule_http_match")

    @rule_http_match.setter
    def rule_http_match(self, value: Optional[pulumi.Input['RouteStageRuleRuleHttpMatchArgs']]):
        pulumi.set(self, "rule_http_match", value)

    @_builtins.property
    @pulumi.getter(name="wafStageId")
    def waf_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the WAF stage that requests matching the rule should be forwarded to. Conflicts with `backend_stage_id` within the same rule.
        """
        return pulumi.get(self, "waf_stage_id")

    @waf_stage_id.setter
    def waf_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "waf_stage_id", value)


if not MYPY:
    class RouteStageRuleRuleHttpMatchArgsDict(TypedDict):
        method_filters: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        HTTP methods to filter for. A request using any of these methods will be considered to match the rule. Possible values are `get`, `post`, `put`, `patch`, `delete`, `head`, `options`. All methods will match if none is provided.
        """
        path_filter: NotRequired[pulumi.Input['RouteStageRuleRuleHttpMatchPathFilterArgsDict']]
        """
        HTTP URL path to filter for. A request whose path matches the given filter will be considered to match the rule. All paths will match if none is provided.
        """
elif False:
    RouteStageRuleRuleHttpMatchArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteStageRuleRuleHttpMatchArgs:
    def __init__(__self__, *,
                 method_filters: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 path_filter: Optional[pulumi.Input['RouteStageRuleRuleHttpMatchPathFilterArgs']] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] method_filters: HTTP methods to filter for. A request using any of these methods will be considered to match the rule. Possible values are `get`, `post`, `put`, `patch`, `delete`, `head`, `options`. All methods will match if none is provided.
        :param pulumi.Input['RouteStageRuleRuleHttpMatchPathFilterArgs'] path_filter: HTTP URL path to filter for. A request whose path matches the given filter will be considered to match the rule. All paths will match if none is provided.
        """
        if method_filters is not None:
            pulumi.set(__self__, "method_filters", method_filters)
        if path_filter is not None:
            pulumi.set(__self__, "path_filter", path_filter)

    @_builtins.property
    @pulumi.getter(name="methodFilters")
    def method_filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        HTTP methods to filter for. A request using any of these methods will be considered to match the rule. Possible values are `get`, `post`, `put`, `patch`, `delete`, `head`, `options`. All methods will match if none is provided.
        """
        return pulumi.get(self, "method_filters")

    @method_filters.setter
    def method_filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "method_filters", value)

    @_builtins.property
    @pulumi.getter(name="pathFilter")
    def path_filter(self) -> Optional[pulumi.Input['RouteStageRuleRuleHttpMatchPathFilterArgs']]:
        """
        HTTP URL path to filter for. A request whose path matches the given filter will be considered to match the rule. All paths will match if none is provided.
        """
        return pulumi.get(self, "path_filter")

    @path_filter.setter
    def path_filter(self, value: Optional[pulumi.Input['RouteStageRuleRuleHttpMatchPathFilterArgs']]):
        pulumi.set(self, "path_filter", value)


if not MYPY:
    class RouteStageRuleRuleHttpMatchPathFilterArgsDict(TypedDict):
        path_filter_type: pulumi.Input[_builtins.str]
        """
        The type of filter to match for the HTTP URL path. For now, all path filters must be written in regex and use the `regex` type.
        """
        value: pulumi.Input[_builtins.str]
        """
        The value to be matched for the HTTP URL path.
        """
elif False:
    RouteStageRuleRuleHttpMatchPathFilterArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RouteStageRuleRuleHttpMatchPathFilterArgs:
    def __init__(__self__, *,
                 path_filter_type: pulumi.Input[_builtins.str],
                 value: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] path_filter_type: The type of filter to match for the HTTP URL path. For now, all path filters must be written in regex and use the `regex` type.
        :param pulumi.Input[_builtins.str] value: The value to be matched for the HTTP URL path.
        """
        pulumi.set(__self__, "path_filter_type", path_filter_type)
        pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="pathFilterType")
    def path_filter_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of filter to match for the HTTP URL path. For now, all path filters must be written in regex and use the `regex` type.
        """
        return pulumi.get(self, "path_filter_type")

    @path_filter_type.setter
    def path_filter_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "path_filter_type", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Input[_builtins.str]:
        """
        The value to be matched for the HTTP URL path.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "value", value)


if not MYPY:
    class TlsStageSecretArgsDict(TypedDict):
        region: NotRequired[pulumi.Input[_builtins.str]]
        """
        The region of the secret.
        """
        secret_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the Secret
        """
elif False:
    TlsStageSecretArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TlsStageSecretArgs:
    def __init__(__self__, *,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] region: The region of the secret.
        :param pulumi.Input[_builtins.str] secret_id: The ID of the Secret
        """
        if region is not None:
            pulumi.set(__self__, "region", region)
        if secret_id is not None:
            pulumi.set(__self__, "secret_id", secret_id)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region of the secret.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Secret
        """
        return pulumi.get(self, "secret_id")

    @secret_id.setter
    def secret_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_id", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetWafStageResult',
    'AwaitableGetWafStageResult',
    'get_waf_stage',
    'get_waf_stage_output',
]

@pulumi.output_type
class GetWafStageResult:
    """
    A collection of values returned by getWafStage.
    """
    def __init__(__self__, backend_stage_id=None, created_at=None, id=None, mode=None, paranoia_level=None, pipeline_id=None, project_id=None, updated_at=None, waf_stage_id=None):
        if backend_stage_id and not isinstance(backend_stage_id, str):
            raise TypeError("Expected argument 'backend_stage_id' to be a str")
        pulumi.set(__self__, "backend_stage_id", backend_stage_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if mode and not isinstance(mode, str):
            raise TypeError("Expected argument 'mode' to be a str")
        pulumi.set(__self__, "mode", mode)
        if paranoia_level and not isinstance(paranoia_level, int):
            raise TypeError("Expected argument 'paranoia_level' to be a int")
        pulumi.set(__self__, "paranoia_level", paranoia_level)
        if pipeline_id and not isinstance(pipeline_id, str):
            raise TypeError("Expected argument 'pipeline_id' to be a str")
        pulumi.set(__self__, "pipeline_id", pipeline_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if waf_stage_id and not isinstance(waf_stage_id, str):
            raise TypeError("Expected argument 'waf_stage_id' to be a str")
        pulumi.set(__self__, "waf_stage_id", waf_stage_id)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> _builtins.str:
        return pulumi.get(self, "backend_stage_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def mode(self) -> _builtins.str:
        return pulumi.get(self, "mode")

    @_builtins.property
    @pulumi.getter(name="paranoiaLevel")
    def paranoia_level(self) -> _builtins.int:
        return pulumi.get(self, "paranoia_level")

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "pipeline_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="wafStageId")
    def waf_stage_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "waf_stage_id")


class AwaitableGetWafStageResult(GetWafStageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWafStageResult(
            backend_stage_id=self.backend_stage_id,
            created_at=self.created_at,
            id=self.id,
            mode=self.mode,
            paranoia_level=self.paranoia_level,
            pipeline_id=self.pipeline_id,
            project_id=self.project_id,
            updated_at=self.updated_at,
            waf_stage_id=self.waf_stage_id)


def get_waf_stage(pipeline_id: Optional[_builtins.str] = None,
                  waf_stage_id: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWafStageResult:
    """
    Gets information about an Edge Services WAF (Web Application Firewall) stage.

    A WAF stage provides web application firewall protection for an Edge Services pipeline, inspecting HTTP requests and blocking malicious traffic based on a configurable paranoia level.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services WAF stage by its ID
    by_id = scaleway.edgeservices.get_waf_stage(waf_stage_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services WAF stage by pipeline ID
    by_pipeline = scaleway.edgeservices.get_waf_stage(pipeline_id=main["id"])
    ```


    :param _builtins.str pipeline_id: The ID of the pipeline.
    :param _builtins.str waf_stage_id: The ID of the WAF stage. Conflicts with all filter arguments below.
           
           The following filter arguments are supported (cannot be used with `waf_stage_id`):
    """
    __args__ = dict()
    __args__['pipelineId'] = pipeline_id
    __args__['wafStageId'] = waf_stage_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:edgeservices/getWafStage:getWafStage', __args__, opts=opts, typ=GetWafStageResult).value

    return AwaitableGetWafStageResult(
        backend_stage_id=pulumi.get(__ret__, 'backend_stage_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        mode=pulumi.get(__ret__, 'mode'),
        paranoia_level=pulumi.get(__ret__, 'paranoia_level'),
        pipeline_id=pulumi.get(__ret__, 'pipeline_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        waf_stage_id=pulumi.get(__ret__, 'waf_stage_id'))
def get_waf_stage_output(pipeline_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         waf_stage_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetWafStageResult]:
    """
    Gets information about an Edge Services WAF (Web Application Firewall) stage.

    A WAF stage provides web application firewall protection for an Edge Services pipeline, inspecting HTTP requests and blocking malicious traffic based on a configurable paranoia level.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services WAF stage by its ID
    by_id = scaleway.edgeservices.get_waf_stage(waf_stage_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services WAF stage by pipeline ID
    by_pipeline = scaleway.edgeservices.get_waf_stage(pipeline_id=main["id"])
    ```


    :param _builtins.str pipeline_id: The ID of the pipeline.
    :param _builtins.str waf_stage_id: The ID of the WAF stage. Conflicts with all filter arguments below.
           
           The following filter arguments are supported (cannot be used with `waf_stage_id`):
    """
    __args__ = dict()
    __args__['pipelineId'] = pipeline_id
    __args__['wafStageId'] = waf_stage_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:edgeservices/getWafStage:getWafStage', __args__, opts=opts, typ=GetWafStageResult)
    return __ret__.apply(lambda __response__: GetWafStageResult(
        backend_stage_id=pulumi.get(__response__, 'backend_stage_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        mode=pulumi.get(__response__, 'mode'),
        paranoia_level=pulumi.get(__response__, 'paranoia_level'),
        pipeline_id=pulumi.get(__response__, 'pipeline_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        waf_stage_id=pulumi.get(__response__, 'waf_stage_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetProjectsResult',
    'AwaitableGetProjectsResult',
    'get_projects',
    'get_projects_output',
]

@pulumi.output_type
class GetProjectsResult:
    """
    A collection of values returned by getProjects.
    """
    def __init__(__self__, created_at=None, description=None, id=None, name=None, organization_id=None, projects=None, updated_at=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if projects and not isinstance(projects, list):
            raise TypeError("Expected argument 'projects' to be a list")
        pulumi.set(__self__, "projects", projects)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        (Computed) The date and time when the project was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        (Computed) The description of the project.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (Computed) The name of the project.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        """
        (Computed) The unique identifier of the organization with which the project is associated.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter
    def projects(self) -> Sequence['outputs.GetProjectsProjectResult']:
        """
        (Computed) A list of projects. Each project has the following attributes:
        """
        return pulumi.get(self, "projects")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        (Computed) The date and time when the project was updated.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetProjectsResult(GetProjectsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectsResult(
            created_at=self.created_at,
            description=self.description,
            id=self.id,
            name=self.name,
            organization_id=self.organization_id,
            projects=self.projects,
            updated_at=self.updated_at)


def get_projects(organization_id: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectsResult:
    """
    The `account_get_projects` data source is used to list all Scaleway projects in an Organization.

    Refer to the Organizations and Projects [documentation](https://www.scaleway.com/en/docs/organizations-and-projects/) and [API documentation](https://www.scaleway.com/en/developers/api/account/project-api/) for more information.

    ## Retrieve a Scaleway Projects

    The following commands allow you to:

    - retrieve all Projects in an Organization

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get all Projects in an Organization
    all = scaleway.account.get_projects(organization_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx")
    ```

    ## Example Usage

    ### Deploy an SSH key in all your organization's projects

    ```python
    import pulumi
    import pulumi_scaleway as scaleway
    import pulumiverse_scaleway as scaleway

    all = scaleway.account.get_projects()
    main = []
    def create_main(range_body):
        for range in [{"value": i} for i in range(0, range_body)]:
            main.append(scaleway.account.SshKey(f"main-{range['value']}",
                name="main",
                public_key=public_key,
                project_id=all.projects[range["value"]].id))

    (len(all.projects)).apply(create_main)
    ```


    :param _builtins.str organization_id: The unique identifier of the Organization with which the Projects are associated.
           If no default `organization_id` is set, one must be set explicitly in this datasource
    """
    __args__ = dict()
    __args__['organizationId'] = organization_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:account/getProjects:getProjects', __args__, opts=opts, typ=GetProjectsResult).value

    return AwaitableGetProjectsResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        projects=pulumi.get(__ret__, 'projects'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_projects_output(organization_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectsResult]:
    """
    The `account_get_projects` data source is used to list all Scaleway projects in an Organization.

    Refer to the Organizations and Projects [documentation](https://www.scaleway.com/en/docs/organizations-and-projects/) and [API documentation](https://www.scaleway.com/en/developers/api/account/project-api/) for more information.

    ## Retrieve a Scaleway Projects

    The following commands allow you to:

    - retrieve all Projects in an Organization

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get all Projects in an Organization
    all = scaleway.account.get_projects(organization_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx")
    ```

    ## Example Usage

    ### Deploy an SSH key in all your organization's projects

    ```python
    import pulumi
    import pulumi_scaleway as scaleway
    import pulumiverse_scaleway as scaleway

    all = scaleway.account.get_projects()
    main = []
    def create_main(range_body):
        for range in [{"value": i} for i in range(0, range_body)]:
            main.append(scaleway.account.SshKey(f"main-{range['value']}",
                name="main",
                public_key=public_key,
                project_id=all.projects[range["value"]].id))

    (len(all.projects)).apply(create_main)
    ```


    :param _builtins.str organization_id: The unique identifier of the Organization with which the Projects are associated.
           If no default `organization_id` is set, one must be set explicitly in this datasource
    """
    __args__ = dict()
    __args__['organizationId'] = organization_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:account/getProjects:getProjects', __args__, opts=opts, typ=GetProjectsResult)
    return __ret__.apply(lambda __response__: GetProjectsResult(
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        projects=pulumi.get(__response__, 'projects'),
        updated_at=pulumi.get(__response__, 'updated_at')))
